'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var useIntl = require('use-intl');
var navigation = require('next/navigation');
var React = require('react');
var Link = require('next/link');
var router = require('next/router');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var Link__default = /*#__PURE__*/_interopDefaultLegacy(Link);

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

// Reuse the legacy cookie name
// https://nextjs.org/docs/advanced-features/i18n-routing#leveraging-the-next_locale-cookie
var COOKIE_LOCALE_NAME = 'NEXT_LOCALE'; // Should take precedence over the cookie

function localizeHref(locale, href) {
  var localizedHref = '/' + locale;

  if (href !== '/') {
    localizedHref += href;
  }

  return localizedHref;
}

function getCookieValueByName(name) {
  // https://stackoverflow.com/a/15724300/343045
  var value = "; " + document.cookie;
  var parts = value.split("; " + name + "=");

  if (parts.length === 2) {
    var _parts$pop;

    var part = (_parts$pop = parts.pop()) == null ? void 0 : _parts$pop.split(';').shift();
    if (part) return part;
  }

  throw new Error("Unable to find next-intl cookie, have you configured the middleware?");
}

function getCookieLocale() {
  return getCookieValueByName(COOKIE_LOCALE_NAME);
}

function useLocalizedRouter() {
  var router = navigation.useRouter();
  return React.useMemo(function () {
    return _extends({}, router, {
      push: function push(href) {
        return router.push(localizeHref(getCookieLocale(), href));
      },
      replace: function replace(href) {
        return router.replace(localizeHref(getCookieLocale(), href));
      },
      prefetch: function prefetch(href) {
        return router.prefetch(localizeHref(getCookieLocale(), href));
      }
    });
  }, [router]);
}

// during the beta, remove for stable release

var hasWarned = false;
function useLocalizedRouterDeprecated() {
  if (!hasWarned) {
    console.warn("\n\nDEPRECATION WARNING: The `useLocalizedRouter` import from `next-intl` is deprecated and will be removed in the stable release of next-intl. Please import `useLocalizedRouter` from `next-intl/client` instead. See https://next-intl-docs.vercel.app/docs/next-13/server-components\n\n");
    hasWarned = true;
  }

  return useLocalizedRouter();
}

var _excluded$1 = ["href", "locale"];
function createLocalizedLinkComponent(useLocale) {
  /**
   * Wraps `next/link` and prefixes the `href` with the current locale.
   */
  function LocalizedLink(_ref, ref) {
    var href = _ref.href,
        locale = _ref.locale,
        rest = _objectWithoutPropertiesLoose(_ref, _excluded$1);

    var curLocale = useLocale();
    if (!locale) locale = curLocale;
    var localizedHref;

    if (typeof href === 'string') {
      localizedHref = localizeHref(locale, href);
    } else {
      localizedHref = _extends({}, href);

      if (href.pathname) {
        localizedHref.pathname = localizeHref(locale, href.pathname);
      }
    }

    return React__default["default"].createElement(Link__default["default"], _extends({
      ref: ref,
      href: localizedHref
    }, rest));
  }

  return React.forwardRef(LocalizedLink);
}

var LocalizedLink = /*#__PURE__*/createLocalizedLinkComponent(useIntl.useLocale);

var _excluded = ["children", "locale"];
function NextIntlClientProvider(_ref) {
  var children = _ref.children,
      locale = _ref.locale,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded);

  var router$1;

  try {
    // Reading from context is practically ok to do conditionally
    // eslint-disable-next-line react-hooks/rules-of-hooks
    router$1 = router.useRouter();
  } catch (error) {// Calling `useRouter` is not supported in the app folder
  } // The router can be undefined if used in a context outside
  // of Next.js (e.g. unit tests, Storybook, ...)


  if (!locale && router$1) {
    locale = router$1.locale;
  }

  if (!locale) {
    throw new Error("Couldn't determine locale. Please pass an explicit `locale` prop the provider, or if you're using the `pages` folder, use internationalized routing (https://nextjs.org/docs/advanced-features/i18n-routing)." );
  }

  return React__default["default"].createElement(useIntl.IntlProvider, _extends({
    locale: locale
  }, rest), children);
}

exports.LocalizedLink = LocalizedLink;
exports.NextIntlProvider = NextIntlClientProvider;
exports.useLocalizedRouter = useLocalizedRouterDeprecated;
Object.keys(useIntl).forEach(function (k) {
  if (k !== 'default' && !exports.hasOwnProperty(k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return useIntl[k]; }
  });
});
//# sourceMappingURL=next-intl.cjs.development.js.map
