import { objectWithoutPropertiesLoose as _objectWithoutPropertiesLoose, extends as _extends } from '../_virtual/next-intl.esm.js';
import Link from 'next/link';
import React, { forwardRef } from 'react';
import localizeHref from './next-intl.esm3.js';

var _excluded = ["href", "locale"];
function createLocalizedLinkComponent(useLocale) {
  /**
   * Wraps `next/link` and prefixes the `href` with the current locale.
   */
  function LocalizedLink(_ref, ref) {
    var href = _ref.href,
        locale = _ref.locale,
        rest = _objectWithoutPropertiesLoose(_ref, _excluded);

    var curLocale = useLocale();
    if (!locale) locale = curLocale;
    var localizedHref;

    if (typeof href === 'string') {
      localizedHref = localizeHref(locale, href);
    } else {
      localizedHref = _extends({}, href);

      if (href.pathname) {
        localizedHref.pathname = localizeHref(locale, href.pathname);
      }
    }

    return React.createElement(Link, _extends({
      ref: ref,
      href: localizedHref
    }, rest));
  }

  return forwardRef(LocalizedLink);
}

export { createLocalizedLinkComponent as default };
//# sourceMappingURL=next-intl.esm.js.map
